@@ -1,15 +1,21 @@
 use 5.14.0;
 
-package Map::Metro::Plugin::Map::Oslo  {
-$Map::Metro::Plugin::Map::Oslo::VERSION = '0.1001';
-use Moose;
-    use File::ShareDir 'dist_dir';
-    use Path::Tiny;
-    with 'Map::Metro::Plugin::Map';
+package Map::Metro::Plugin::Map::Oslo;
 
-    has '+mapfile' => (
-        default => sub { path(dist_dir('Map-Metro-Plugin-Map-Oslo'))->child('map-oslo.metro')->absolute },
-    );
+our $VERSION = '0.1100'; # VERSION
+
+use Moose;
+
+with 'Map::Metro::Plugin::Map';
+
+has '+mapfile' => (
+    default => 'map-oslo.metro',
+);
+sub map_version {
+    return $VERSION;
+}
+sub map_package {
+    return __PACKAGE__;
 }
 
 1;
@@ -33,13 +39,12 @@ See L<Map::Metro> for usage information.
 
 =head1 Status
 
-This map is currently (2014-12-19) believed to be correct, with these disclaimers:
+This map is currently (2014-12-19) believed to be correct (L<wikipedia|https://en.wikipedia.org/wiki/Oslo_metro>).
+
+Note:
 
 * Line 1 stops at Helsfyr.
 
-* Line 1 stops at Gulleråsen in both directions.
-
-
 =head1 AUTHOR
 
 Erik Carlsson E<lt>info@code301.comE<gt>
